@@ -1,5 +1,5 @@
 /*  ADCD - A Diminutive CD player for Linux
-    Copyright (C) 2004 Antonio Diaz Diaz.
+    Copyright (C) 2004, 2005 Antonio Diaz Diaz.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -54,8 +54,8 @@ class CD
   int _first_track;		// first track on current disc (not always 1)
   int _last_track;		// last track on current disc
   size_t _index;		// index in playlist
+  int _loop;			// Loop mode (0=no_loop, 1=Loop, 2=Loop1)
   bool _linear;			// Linear/Playlist mode
-  bool _loop;			// Loop mode
   std::vector< int > _playlist;
   std::vector< Track_times > _timelist;
 
@@ -79,8 +79,9 @@ public:
   int  index() const throw() { return _index; }
   bool linear() const throw() { return _linear; }
   void linear( bool new_linear ) throw() { _linear = new_linear; }
-  bool loop() const throw() { return _loop; }
-  void loop( bool new_loop ) throw() { _loop = new_loop; }
+  int loop() const throw() { return _loop; }
+  void loop( int new_loop ) throw();
+  char * loop_name() const throw();
   const std::vector< int > & playlist() const throw() { return _playlist; }
   void playlist( const std::vector< int > & pl ) throw();
   char * status_name() const throw();
@@ -97,6 +98,6 @@ public:
 
   enum Time_mode { relative, rem_rel, absolute, rem_abs };
   Msf_time time( Time_mode mode ) const throw();
-  Msf_time time_begin( int track ) const throw();
+  Msf_time time_start( int track ) const throw();
   Msf_time time_end( int track ) const throw();
   };
